|
Neko 1.99.9
A portable framework for high-order spectral element flow simulations
|


Go to the source code of this file.

| __global__ void __launch_bounds__ | ( | (LX *LX *EB) | ) |
Device kernel for axhelm with padding in shared memory to remove bank conflicts when LX is a power of 2
| __syncthreads | ( | ) |

| __global__ void ax_helm_kernel_1d | ( | T *__restrict__ | w, |
| const T *__restrict__ | u, | ||
| const T *__restrict__ | dx, | ||
| const T *__restrict__ | dy, | ||
| const T *__restrict__ | dz, | ||
| const T *__restrict__ | dxt, | ||
| const T *__restrict__ | dyt, | ||
| const T *__restrict__ | dzt, | ||
| const T *__restrict__ | h1, | ||
| const T *__restrict__ | g11, | ||
| const T *__restrict__ | g22, | ||
| const T *__restrict__ | g33, | ||
| const T *__restrict__ | g12, | ||
| const T *__restrict__ | g13, | ||
| const T *__restrict__ | g23 | ||
| ) |
Device kernel for axhelm
Definition at line 65 of file ax_helm_kernel.h.

| __global__ void ax_helm_kernel_vector_part2 | ( | T *__restrict__ | au, |
| T *__restrict__ | av, | ||
| T *__restrict__ | aw, | ||
| const T *__restrict__ | u, | ||
| const T *__restrict__ | v, | ||
| const T *__restrict__ | w, | ||
| const T *__restrict__ | h2, | ||
| const T *__restrict__ | B, | ||
| const int | n | ||
| ) |
| for | ( | ) |
| if | ( | active | ) |
| if | ( | eb | = = 0 | ) |
Definition at line 225 of file ax_helm_kernel.h.
Definition at line 217 of file ax_helm_kernel.h.
| __global__ void T* __restrict__ av |
Definition at line 933 of file ax_helm_kernel.h.
| __global__ void T* __restrict__ T* __restrict__ aw |
Definition at line 934 of file ax_helm_kernel.h.
| __global__ void T* __restrict__ T* __restrict__ const T* __restrict__ const T* __restrict__ const T* __restrict__ const T* __restrict__ dx |
Definition at line 175 of file ax_helm_kernel.h.
| __global__ void T* __restrict__ T* __restrict__ const T* __restrict__ const T* __restrict__ const T* __restrict__ const T* __restrict__ const T* __restrict__ dy |
Definition at line 176 of file ax_helm_kernel.h.
| __global__ void T* __restrict__ T* __restrict__ const T* __restrict__ const T* __restrict__ const T* __restrict__ const T* __restrict__ const T* __restrict__ const T* __restrict__ dz |
Definition at line 177 of file ax_helm_kernel.h.
| const int e_blk = blockIdx.x * EB + eb |
Definition at line 216 of file ax_helm_kernel.h.
Definition at line 215 of file ax_helm_kernel.h.
Definition at line 179 of file ax_helm_kernel.h.
Definition at line 182 of file ax_helm_kernel.h.
Definition at line 183 of file ax_helm_kernel.h.
Definition at line 180 of file ax_helm_kernel.h.
Definition at line 184 of file ax_helm_kernel.h.
Definition at line 181 of file ax_helm_kernel.h.
Definition at line 178 of file ax_helm_kernel.h.
| const int i = threadIdx.x |
Definition at line 220 of file ax_helm_kernel.h.
Definition at line 219 of file ax_helm_kernel.h.
Definition at line 185 of file ax_helm_kernel.h.
Definition at line 206 of file ax_helm_kernel.h.
| T rut |
Definition at line 208 of file ax_helm_kernel.h.
Definition at line 987 of file ax_helm_kernel.h.
Definition at line 984 of file ax_helm_kernel.h.
| T rvt |
Definition at line 992 of file ax_helm_kernel.h.
Definition at line 988 of file ax_helm_kernel.h.
Definition at line 207 of file ax_helm_kernel.h.
| T rwt |
Definition at line 993 of file ax_helm_kernel.h.
Definition at line 989 of file ax_helm_kernel.h.
| __shared__ T shdy[LX *(LX+1)] |
Definition at line 189 of file ax_helm_kernel.h.
| __shared__ T shdz[LX *(LX+1)] |
Definition at line 190 of file ax_helm_kernel.h.
| __shared__ T shu[EB *LX *(LX+1)] |
Definition at line 193 of file ax_helm_kernel.h.
| __shared__ T shur[EB *LX *LX] |
Definition at line 194 of file ax_helm_kernel.h.
| __shared__ T shus[EB *LX *(LX+1)] |
Definition at line 195 of file ax_helm_kernel.h.
| __shared__ T shv[EB *LX *(LX+1)] |
Definition at line 960 of file ax_helm_kernel.h.
| __shared__ T shvr[EB *LX *LX] |
Definition at line 961 of file ax_helm_kernel.h.
| __shared__ T shvs[EB *LX *(LX+1)] |
Definition at line 962 of file ax_helm_kernel.h.
| __shared__ T shw[EB *LX *(LX+1)] |
Definition at line 964 of file ax_helm_kernel.h.
| __shared__ T shwr[EB *LX *LX] |
Definition at line 965 of file ax_helm_kernel.h.
| __shared__ T shws[EB *LX *(LX+1)] |
Definition at line 966 of file ax_helm_kernel.h.
Definition at line 174 of file ax_helm_kernel.h.
Definition at line 936 of file ax_helm_kernel.h.
| __global__ void T* __restrict__ T* __restrict__ const T* __restrict__ const T* __restrict__ const T* __restrict__ w |
Definition at line 937 of file ax_helm_kernel.h.